==> pear-Horde_Argv-1.0.5.tbz: share/pear/Horde/Argv/Translation.php <==
<?php
/**
 * @package Argv
 *
 * Copyright 2010-2011 Horde LLC (http://www.horde.org/)
 *
 * See the enclosed file COPYING for license information (LGPL). If you
 * did not receive this file, see http://www.horde.org/licenses/lgpl21.
 */

/**
 * Horde_Argv_Translation is the translation wrapper class for Horde_Argv.
 *
 * @author  Jan Schneider <jan@horde.org>
 * @package Argv
 */
class Horde_Argv_Translation extends Horde_Translation
{
    /**
     * Returns the translation of a message.
     *
     * @var string $message  The string to translate.
     *
     * @return string  The string translation, or the original string if no
     *                 translation exists.
     */
    static public function t($message)
    {
        self::$_domain = 'Horde_Argv';
        self::$_directory = '/usr/local/share/pear/data' == '@'.'data_dir'.'@' ? dirname(__FILE__) . '/../../../locale' : '/usr/local/share/pear/data/Horde_Argv/locale';
        return parent::t($message);
    }

    /**
     * Returns the plural translation of a message.
     *
     * @param string $singular  The singular version to translate.
     * @param string $plural    The plural version to translate.
     * @param integer $number   The number that determines singular vs. plural.
     *
     * @return string  The string translation, or the original string if no
     *                 translation exists.
     */
    static public function ngettext($singular, $plural, $number)
    {
        self::$_domain = 'Horde_Argv';
        self::$_directory = '/usr/local/share/pear/data' == '@'.'data_dir'.'@' ? dirname(__FILE__) . '/../../../locale' : '/usr/local/share/pear/data/Horde_Argv/locale';
        return parent::ngettext($singular, $plural, $number);
    }
}

==> pear-Horde_Argv-2.0.4.tbz: share/pear/Horde/Argv/Translation.php <==
<?php
/**
 * @package Argv
 *
 * Copyright 2010-2013 Horde LLC (http://www.horde.org/)
 *
 * See the enclosed file COPYING for license information (LGPL). If you
 * did not receive this file, see http://www.horde.org/licenses/lgpl21.
 */

/**
 * Horde_Argv_Translation is the translation wrapper class for Horde_Argv.
 *
 * @author  Jan Schneider <jan@horde.org>
 * @package Argv
 */
class Horde_Argv_Translation extends Horde_Translation
{
    /**
     * Returns the translation of a message.
     *
     * @var string $message  The string to translate.
     *
     * @return string  The string translation, or the original string if no
     *                 translation exists.
     */
    static public function t($message)
    {
        self::$_domain = 'Horde_Argv';
        self::$_directory = '/usr/local/share/pear/data' == '@'.'data_dir'.'@' ? __DIR__ . '/../../../locale' : '/usr/local/share/pear/data/Horde_Argv/locale';
        return parent::t($message);
    }

    /**
     * Returns the plural translation of a message.
     *
     * @param string $singular  The singular version to translate.
     * @param string $plural    The plural version to translate.
     * @param integer $number   The number that determines singular vs. plural.
     *
     * @return string  The string translation, or the original string if no
     *                 translation exists.
     */
    static public function ngettext($singular, $plural, $number)
    {
        self::$_domain = 'Horde_Argv';
        self::$_directory = '/usr/local/share/pear/data' == '@'.'data_dir'.'@' ? __DIR__ . '/../../../locale' : '/usr/local/share/pear/data/Horde_Argv/locale';
        return parent::ngettext($singular, $plural, $number);
    }
}
